'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _pickBy = require('lodash/pickBy');

var _pickBy2 = _interopRequireDefault(_pickBy);

var _forEach = require('lodash/forEach');

var _forEach2 = _interopRequireDefault(_forEach);

var _localStorage = require('./local-storage');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = {
    watch: {
        '$data': {
            handler: function handler() {
                this.saveState();
            },

            deep: true
        }
    },

    created: function created() {
        this.loadState();
    },


    methods: {
        loadState: function loadState() {
            var _this = this;

            if (this.getSaveStateConfig().dontSaveState === true) return;
            var savedState = (0, _localStorage.getSavedState)(this.getSaveStateConfig().cacheKey, this.getSaveStateConfig().cacheType);

            if (!savedState) {
                return;
            }

            (0, _forEach2.default)(savedState, function (value, key) {

                if (_this.attributeIsManagedBySaveState(key)) {
                    if (_this.getSaveStateConfig().onLoad) {
                        value = _this.getSaveStateConfig().onLoad(key, value);
                    }

                    _this.$data[key] = value;
                }
            });
        },
        saveState: function saveState() {
            var _this2 = this;

            if (this.getSaveStateConfig().dontSaveState === true) return;
            var data = (0, _pickBy2.default)(this.$data, function (value, attribute) {
                return _this2.attributeIsManagedBySaveState(attribute);
            });
            (0, _localStorage.saveState)(this.getSaveStateConfig().cacheKey, data, this.getSaveStateConfig().cacheType);
        },
        attributeIsManagedBySaveState: function attributeIsManagedBySaveState(attribute) {
            if (this.getSaveStateConfig().ignoreProperties && this.getSaveStateConfig().ignoreProperties.indexOf(attribute) !== -1) {

                return false;
            }

            if (!this.getSaveStateConfig().saveProperties) {
                return true;
            }

            return this.getSaveStateConfig().saveProperties.indexOf(attribute) !== -1;
        },
        clearSavedState: function clearSavedState() {
            (0, _localStorage.clearSavedState)(this.getSaveStateConfig().cacheKey, this.getSaveStateConfig().cacheType);
        }
    }
};